/**
 * @file
 * JS for Responsive Panels Regions.
 */

(function ($) {

  "use strict";

  // These variables are used for handling the mobile menus on screen resize
  var isMobile = false;
  var mobileMenus = [];
  var tracker = 1;

  function setCookie(cname, cvalue, exdays) {
    var d = new Date();
    d.setTime(d.getTime() + (exdays*24*60*60*1000));
    var expires = "expires="+d.toUTCString();
    document.cookie = cname + "=" + cvalue + "; " + expires + "; path=/";
  }

  function getCookie(cname) {
    var name = cname + "=";
    var ca = document.cookie.split(';');
    for(var i=0; i<ca.length; i++) {
      var c = ca[i];
      while (c.charAt(0)==' ') c = c.substring(1);
      if (c.indexOf(name) == 0) return c.substring(name.length,c.length);
    }
    return "";
  }

  function saveState(position) {
    // save the toggle state in cookie
    // Cookie plugin not loaded for anonymous users
    if ($.cookie) {
      var state = $('body').hasClass('oa-responsive-region-' + position + '-on');
      setCookie("oa-responsive-regions-" + position, state, 365)
    }
  }

  function getState(position) {
    // return the cookie state
    if ($.cookie) {
      var state = getCookie("oa-responsive-regions-" + position);
      return state;
    }
    return false;
  }

  function debounce(func, wait, immediate) {
    var timeout;
    return function() {
      var context = this, args = arguments;
      var later = function() {
        timeout = null;
        if (!immediate) func.apply(context, args);
      };
      var callNow = immediate && !timeout;
      clearTimeout(timeout);
      timeout = setTimeout(later, wait);
      if (callNow) func.apply(context, args);
    };
  }

  function maxSidebarHeight() {
    var region = $('.oa-responsive-primary');
    var viewport = $(window).height();
    if (region.length) {
      var toolbarHeight = 0;
      var toolbar = $('.panel-panel-inner .oa-responsive-region-bottom.oa-responsive-fixed');
      if (toolbar.length) {
        toolbarHeight += $(toolbar).height();
        $(region).css('padding-bottom', $(toolbar).height());
      }
      var toolbar = $('.panel-panel-inner .oa-responsive-region-top.oa-responsive-fixed');
      if (toolbar.length) {
        toolbarHeight += $(toolbar).height();
        $(region).css('padding-top', $(toolbar).height());
      }
      viewport = viewport - toolbarHeight;
      var h = region.height();
      if (h < viewport) {
        $('.oa-responsive-region-right').each(function() {
          $(this).height(viewport);
        });
        $('.oa-responsive-region-left').each(function() {
          $(this).height(viewport);
        });
      }
    }
  }

  function setMenu() {
    if (isMobile) {
      // wire the mobile admin
      if (($('#toolbar-menu-button').length > 0) && ($('#oa-navbar-admin').length > 0)) {
        $('#navbar-tray .navbar-menu-administration').attr('menu-desktop', tracker)
          .children('ul').attr('menu-item', tracker).appendTo("#oa-navbar-admin .oa-navbar-inner");
        tracker++;
      }
      else {
        $('.oa-navbar button.navbar-toggle.admin').hide();
      }

      // move each menu, Bootstrap handles the menu toggle
      $.each(mobileMenus, function(i, val) {
        $("."+val+"-mobile-menu").each(function() {
          if ($(this).hasClass('oa-mobile-expand')) {
            // defer expanded items
          }
          else {
            $(this).find('.pane-content').appendTo("#oa-navbar-" + val + " .oa-navbar-inner");
          }
        });
      });
      // Now handle submenus to be appended and expanded
      $.each(mobileMenus, function(i, val) {
        $("."+val+"-mobile-menu").each(function() {
          if ($(this).hasClass('oa-mobile-expand')) {
            var item = $(this).find('.pane-content ul.dropdown-menu').appendTo("#oa-navbar-" + val + " .oa-navbar-inner");
            item.addClass('oa-mobile-expanded');
          }
        });
      });
    }
  }

  function fixMobileMenus() {
    if ($('button.navbar-toggle').is(':visible') != isMobile) {
      if (isMobile == true) {
        //there was a change, if isMobile was true the change is to false and is now desktop
        //here we want to move the menu items back
        for (var i = 1; i <= tracker; i++) {
          $('.oa-navbar').find("[menu-item='" + i +"']").appendTo("[menu-desktop='" + i +"']");
        }
      }
      isMobile = $('button.navbar-toggle').is(':visible');
      setMenu();
    }
  }

  function fixColumnWidthOnResize() {
    $('.oa-responsive-primary').each(function () {
      var wrapper = $(this).parent().parent();
      var getInline = $(wrapper).attr('style');
      var inlineWidth = getInline.indexOf('width');

      if (($(window).width() < 992) && (inlineWidth > -1)) {
        // Screen smaller than 992 and we have a width already set
        // We need to clear the width and bring back the first style property
        $(wrapper).attr('style', 'display: block;');
      } else if (($(window).width() > 991 && (inlineWidth == -1))) {
        // Screen is larger than 991 and we do not have a width set yet
        // We need to calculate the width again and set it
        var wrapperLeft = $('.oa-responsive-region-left').outerWidth();
        var width = $(wrapper).outerWidth() + wrapperLeft;
        var percent = Math.floor(width / $(wrapper).parent().outerWidth() * 100);
        $(wrapper).attr('style', 'display: block; width: ' + percent + '%;');
      }
    });
  }

  Drupal.behaviors.responsive_panels_regions = {
    attach: function(context) {
      function getStyle(el){
        // To determine if width uses % or px, we need to use getComputedStyle
        // But it only works when display is none.
        var display = window.getComputedStyle(el).getPropertyValue("display");
        el.style.display = "none";
        var width = window.getComputedStyle(el).getPropertyValue("width");
        el.style.display = display;
        return width;
      }
      $('.oa-responsive-regions-toggle', context).each(function () {
        $(this).bind('click', function() {
          var position = $(this).data().position;
          Drupal.ResponsivePanelsRegions.toggleRegion(position);
        });
      });
      // Compute the sizes of the responsive regions
      var widths = {left: 0, right: 0, top: 0, bottom: 0};
      var heights = {left: 0, right: 0, top: 0, bottom: 0};
      $('.panel-panel-inner > .oa-responsive-region', context).each(function () {
        if ($(this).css('position') == 'absolute') {
          var position = $(this).data().position;
          var wrapper = $(this).parent().parent();
          widths[position] += $(wrapper).outerWidth();
          heights[position] += $(wrapper).outerHeight();
        }
      });
      // We need to copy the css classes from the panels pane div to its
      // parent grid element (parent.parent)
      $('.panel-panel-inner > .oa-responsive-region', context).each(function () {
        var position = $(this).data().position;
        var wrapper = $(this).parent().parent();
        if ((position != 'center') && (position != 'fluid')) {
          $(wrapper).addClass($(this).attr('class'));
          // Prevent absolute positioning on parent row when bar is fixed and expanded
          if ($(wrapper).hasClass('oa-responsive-expand') && $(wrapper).hasClass('oa-responsive-fixed')) {
            $(wrapper).removeClass('oa-responsive-region-' + position);
          }
          // Prevent parent row from being fixed
          $(wrapper).removeClass('oa-responsive-fixed');
        }
        // Regions are initially hidden in css to avoid flicker, so show them now
        $(this).css('display', 'block');
        $(wrapper).parent().addClass('oa-responsive-region-row-' + position);
      });
      // Now adjust the size of the primary region
      $('.oa-responsive-primary', context).each(function () {
        var wrapper = $(this).parent().parent();
        var width = $(wrapper).outerWidth() + widths.left + widths.right;
        var percent = Math.floor(width / $(wrapper).parent().outerWidth() * 100);
        var style = getStyle($(wrapper).get(0));
        // If the original width used % then compute new % otherwise pixels
        if (style && (style != 'auto')) {
          if (style.indexOf('%') >= 0) {
            $(wrapper).css('width', percent + '%');
          }
          else {
            $(wrapper).width(width);
          }
        }
      });
      $('.oa-responsive-regions-toggle', context).each(function () {
        // Restore saved cookie states
        var position = $(this).data().position;
        if (getState(position) == 'true') {
          Drupal.ResponsivePanelsRegions.showRegion(position);
        }
      });
    }
  };

  Drupal.behaviors.mobile_nav_behavior = {
    attach: function(context) {
      isMobile = $('button.navbar-toggle').is(':visible');

      mobileMenus = [];
      // Determine which menu toggles are on page
      $('button.navbar-toggle').each(function () {
        var menuid = $(this).data('target');
        menuid = menuid.replace("#oa-navbar-", "");
        mobileMenus.push(menuid);
      });

      tracker = 1;

      // Handle image in user toggle specially
      var userImg = $('.user-mobile-menu .user-badge img');
      if (userImg.length > 0) {
        var currentUserImg = $('.navbar-toggle.user img');
        // if there is a user image (logged in), then put it into the mobile button
        // but only once.
        if (currentUserImg.length == 0) {
          userImg.clone().appendTo('.navbar-toggle.user');
        }
      }
      else {
        // if no image, then move the Login link
        var currentLink = $('.navbar-toggle.user .user-badge');
        if (currentLink.length == 0) {
          $('.user-mobile-menu .user-badge').clone().appendTo('.navbar-toggle.user');
        }
      }
      $.each(mobileMenus, function(i, val) {
        $("."+val+"-mobile-menu").find('.pane-content').each( function() {
          $(this).attr('menu-item', tracker).parent().attr('menu-desktop', tracker);
          tracker++;
        });
      });

      setMenu();
    }
  };

  Drupal.ResponsivePanelsRegions = Drupal.ResponsivePanelsRegions || {
    toggleRegion: function(position) {
      $('body').toggleClass('oa-responsive-region-' + position + '-on');
      $('.btn-' + position).toggleClass('btn-active');
      saveState(position);
    },
    // Provide some helper classes.
    showRegion: function(position) {
      $('body').addClass('oa-responsive-region-' + position + '-on');
      $('.btn-' + position).addClass('btn-active');
      saveState(position);
    },
    hideRegion: function(position) {
      $('body').removeClass('oa-responsive-region-' + position + '-on');
      $('.btn-active').removeClass('btn-active');
      saveState(position);
    }
  };

  var sidebarHeight = debounce(function(){
    maxSidebarHeight();
  }, 250);
  var fixColumnWidth = debounce(function(){
    fixColumnWidthOnResize();
  }, 250);
  var moveMobileMenus = debounce(function(){
    fixMobileMenus();
  }, 250);

  window.addEventListener('load', sidebarHeight);
  window.addEventListener('resize', sidebarHeight);
  window.addEventListener('resize', fixColumnWidth);
  window.addEventListener('resize', moveMobileMenus);

})(jQuery);
;

/**
 * @file: Popup dialog interfaces for the media project.
 *
 * Drupal.media.popups.mediaBrowser
 *   Launches the media browser which allows users to pick a piece of media.
 *
 * Drupal.media.popups.mediaStyleSelector
 *  Launches the style selection form where the user can choose what
 *  format/style they want their media in.
 */

(function ($) {
namespace('Drupal.media.popups');

/**
 * Media browser popup. Creates a media browser dialog.
 *
 * @param {function}
 *   onSelect Callback for when dialog is closed, received (Array media, Object
 *   extra);
 * @param {Object}
 *   globalOptions Global options that will get passed upon initialization of
 *   the browser. @see Drupal.media.popups.mediaBrowser.getDefaults();
 * @param {Object}
 *   pluginOptions Options for specific plugins. These are passed to the plugin
 *   upon initialization.  If a function is passed here as a callback, it is
 *   obviously not passed, but is accessible to the plugin in
 *   Drupal.settings.variables. Example:
 *   pluginOptions = {library: {url_include_patterns:'/foo/bar'}};
 * @param {Object}
 *   widgetOptions Options controlling the appearance and behavior of the modal
 *   dialog. @see Drupal.media.popups.mediaBrowser.getDefaults();
 */
Drupal.media.popups.mediaBrowser = function (onSelect, globalOptions, pluginOptions, widgetOptions) {
  // Get default dialog options.
  var options = Drupal.media.popups.mediaBrowser.getDefaults();

  // Add global, plugin and widget options.
  options.global = $.extend({}, options.global, globalOptions);
  options.plugins = pluginOptions;
  options.widget = $.extend({}, options.widget, widgetOptions);

  // Find the URL of the modal iFrame.
  var browserSrc = options.widget.src;

  if ($.isArray(browserSrc) && browserSrc.length) {
    browserSrc = browserSrc[browserSrc.length - 1];
  }

  // Create an array of parameters to send along to the iFrame.
  var params = {};

  // Add global field widget settings and plugin information.
  $.extend(params, options.global);
  params.plugins = options.plugins;

  // Append the list of parameters to the iFrame URL as query parameters.
  browserSrc += '&' + $.param(params);

  // Create an iFrame with the iFrame URL.
  var mediaIframe = Drupal.media.popups.getPopupIframe(browserSrc, 'mediaBrowser');

  // Attach an onLoad event.
  mediaIframe.bind('load', options, options.widget.onLoad);

  // Create an array of Dialog options.
  var dialogOptions = options.dialog;

  // Setup the dialog buttons.
  var ok = Drupal.t('OK');
  var notSelected = Drupal.t('You have not selected anything!');

  dialogOptions.buttons[ok] = function () {
    // Find the current file selection.
    var selected = this.contentWindow.Drupal.media.browser.selectedMedia;

    // Alert the user if a selection has yet to be made.
    if (selected.length < 1) {
      alert(notSelected);

      return;
    }

    // Select the file.
    onSelect(selected);

    // Close the dialog.
    $(this).dialog('close');
  };

  // Create a jQuery UI dialog with the given options.
  var dialog = mediaIframe.dialog(dialogOptions);

  // Allow the dialog to react to re-sizing, scrolling, etc.
  Drupal.media.popups.sizeDialog(dialog);
  Drupal.media.popups.resizeDialog(dialog);
  Drupal.media.popups.scrollDialog(dialog);
  Drupal.media.popups.overlayDisplace(dialog.parents(".ui-dialog"));

  return mediaIframe;
};

/**
 * Retrieves a list of default settings for the media browser.
 *
 * @return
 *   An array of default settings.
 */
Drupal.media.popups.mediaBrowser.getDefaults = function () {
  return {
    global: {
      types: [], // Types to allow, defaults to all.
      enabledPlugins: [] // If provided, a list of plugins which should be enabled.
    },
    widget: { // Settings for the actual iFrame which is launched.
      src: Drupal.settings.media.browserUrl, // Src of the media browser (if you want to totally override it)
      onLoad: Drupal.media.popups.mediaBrowser.mediaBrowserOnLoad // Onload function when iFrame loads.
    },
    dialog: Drupal.media.popups.getDialogOptions()
  };
};

/**
 * Sets up the iFrame buttons.
 */
Drupal.media.popups.mediaBrowser.mediaBrowserOnLoad = function (e) {
  var options = e.data;

  // Ensure that the iFrame is defined.
  if (typeof this.contentWindow.Drupal.media === 'undefined' || typeof
  this.contentWindow.Drupal.media.browser === 'undefined') {
    return;
  }

  // Check if a selection has been made and press the 'ok' button.
  if (this.contentWindow.Drupal.media.browser.selectedMedia.length > 0) {
    var ok = Drupal.t('OK');
    var ok_func = $(this).dialog('option', 'buttons')[ok];

    ok_func.call(this);

    return;
  }
};

/**
 * Finalizes the selection of a file.
 *
 * Alerts the user if a selection has yet to be made, triggers the file
 * selection and closes the modal dialog.
 */
Drupal.media.popups.mediaBrowser.finalizeSelection = function () {
  // Find the current file selection.
  var selected = this.contentWindow.Drupal.media.browser.selectedMedia;

  // Alert the user if a selection has yet to be made.
  if (selected.length < 1) {
    alert(notSelected);

    return;
  }

  // Select the file.
  onSelect(selected);

  // Close the dialog.
  $(this).dialog('close');
};

/**
 * Style chooser Popup. Creates a dialog for a user to choose a media style.
 *
 * @param mediaFile
 *   The mediaFile you are requesting this formatting form for.
 *   @todo: should this be fid? That's actually all we need now.
 *
 * @param Function
 *   onSubmit Function to be called when the user chooses a media style. Takes
 *   one parameter (Object formattedMedia).
 *
 * @param Object
 *   options Options for the mediaStyleChooser dialog.
 */
Drupal.media.popups.mediaStyleSelector = function (mediaFile, onSelect, options) {
  var defaults = Drupal.media.popups.mediaStyleSelector.getDefaults();

  // @todo: remove this awful hack :(
  if (typeof defaults.src === 'string' ) {
    defaults.src = defaults.src.replace('-media_id-', mediaFile.fid) + '&fields=' + encodeURIComponent(JSON.stringify(mediaFile.fields));
  }
  else {
    var src = defaults.src.shift();

    defaults.src.unshift(src);
    defaults.src = src.replace('-media_id-', mediaFile.fid) + '&fields=' + encodeURIComponent(JSON.stringify(mediaFile.fields));
  }

  options = $.extend({}, defaults, options);

  // Create an iFrame with the iFrame URL.
  var mediaIframe = Drupal.media.popups.getPopupIframe(options.src, 'mediaStyleSelector');

  // Attach an onLoad event.
  mediaIframe.bind('load', options, options.onLoad);

  // Create an array of Dialog options.
  var dialogOptions = Drupal.media.popups.getDialogOptions();

  // Setup the dialog buttons.
  var ok = Drupal.t('OK');
  var notSelected = Drupal.t('Very sorry, there was an unknown error embedding media.');

  dialogOptions.buttons[ok] = function () {
    // Find the current file selection.
    var formattedMedia = this.contentWindow.Drupal.media.formatForm.getFormattedMedia();
    formattedMedia.options = $.extend({}, mediaFile.attributes, formattedMedia.options);

    // Alert the user if a selection has yet to be made.
    if (!formattedMedia) {
      alert(notSelected);

      return;
    }

    // Select the file.
    onSelect(formattedMedia);

    // Close the dialog.
    $(this).dialog('close');
  };

  // Create a jQuery UI dialog with the given options.
  var dialog = mediaIframe.dialog(dialogOptions);

  // Allow the dialog to react to re-sizing, scrolling, etc.
  Drupal.media.popups.sizeDialog(dialog);
  Drupal.media.popups.resizeDialog(dialog);
  Drupal.media.popups.scrollDialog(dialog);
  Drupal.media.popups.overlayDisplace(dialog.parents(".ui-dialog"));

  return mediaIframe;
};

Drupal.media.popups.mediaStyleSelector.mediaBrowserOnLoad = function (e) {
};

Drupal.media.popups.mediaStyleSelector.getDefaults = function () {
  return {
    src: Drupal.settings.media.styleSelectorUrl,
    onLoad: Drupal.media.popups.mediaStyleSelector.mediaBrowserOnLoad
  };
};

/**
 * Style chooser Popup. Creates a dialog for a user to choose a media style.
 *
 * @param mediaFile
 *   The mediaFile you are requesting this formatting form for.
 *   @todo: should this be fid? That's actually all we need now.
 *
 * @param Function
 *   onSubmit Function to be called when the user chooses a media style. Takes
 *   one parameter (Object formattedMedia).
 *
 * @param Object
 *   options Options for the mediaStyleChooser dialog.
 */
Drupal.media.popups.mediaFieldEditor = function (fid, onSelect, options) {
  var defaults = Drupal.media.popups.mediaFieldEditor.getDefaults();

  // @todo: remove this awful hack :(
  defaults.src = defaults.src.replace('-media_id-', fid);
  options = $.extend({}, defaults, options);

  // Create an iFrame with the iFrame URL.
  var mediaIframe = Drupal.media.popups.getPopupIframe(options.src, 'mediaFieldEditor');

  // Attach an onLoad event.
  mediaIframe.bind('load', options, options.onLoad);

  // Create an array of Dialog options.
  var dialogOptions = Drupal.media.popups.getDialogOptions();

  // Setup the dialog buttons.
  var ok = Drupal.t('OK');
  var notSelected = Drupal.t('Very sorry, there was an unknown error embedding media.');

  dialogOptions.buttons[ok] = function () {
    // Find the current file selection.
    var formattedMedia = this.contentWindow.Drupal.media.formatForm.getFormattedMedia();

    // Alert the user if a selection has yet to be made.
    if (!formattedMedia) {
      alert(notSelected);

      return;
    }

    // Select the file.
    onSelect(formattedMedia);

    // Close the dialog.
    $(this).dialog('close');
  };

  // Create a jQuery UI dialog with the given options.
  var dialog = mediaIframe.dialog(dialogOptions);

  // Allow the dialog to react to re-sizing, scrolling, etc.
  Drupal.media.popups.sizeDialog(dialog);
  Drupal.media.popups.resizeDialog(dialog);
  Drupal.media.popups.scrollDialog(dialog);
  Drupal.media.popups.overlayDisplace(dialog);

  return mediaIframe;
};

Drupal.media.popups.mediaFieldEditor.mediaBrowserOnLoad = function (e) {

};

Drupal.media.popups.mediaFieldEditor.getDefaults = function () {
  return {
    // @todo: do this for real
    src: '/media/-media_id-/edit?render=media-popup',
    onLoad: Drupal.media.popups.mediaFieldEditor.mediaBrowserOnLoad
  };
};

/**
 * Generic functions to both the media-browser and style selector.
 */

/**
 * Returns the commonly used options for the dialog.
 */
Drupal.media.popups.getDialogOptions = function () {
  return {
    title: Drupal.t('Media browser'),
    buttons: {},
    dialogClass: Drupal.settings.media.dialogOptions.dialogclass,
    modal: Drupal.settings.media.dialogOptions.modal,
    draggable: Drupal.settings.media.dialogOptions.draggable,
    resizable: Drupal.settings.media.dialogOptions.resizable,
    minWidth: Drupal.settings.media.dialogOptions.minwidth,
    width: Drupal.settings.media.dialogOptions.width,
    height: Drupal.settings.media.dialogOptions.height,
    position: Drupal.settings.media.dialogOptions.position,
    overlay: {
      backgroundColor: Drupal.settings.media.dialogOptions.overlay.backgroundcolor,
      opacity: Drupal.settings.media.dialogOptions.overlay.opacity
    },
    zIndex: Drupal.settings.media.dialogOptions.zindex,
    close: function (event, ui) {
      var elem = $(event.target);
      var id = elem.attr('id');
      if(id == 'mediaStyleSelector') {
        $(this).dialog("destroy");
        $('#mediaStyleSelector').remove();
      }
      else {
        $(this).dialog("destroy");
        $('#mediaBrowser').remove();
      }
    }
  };
};

/**
 * Get an iframe to serve as the dialog's contents. Common to both plugins.
 */
Drupal.media.popups.getPopupIframe = function (src, id, options) {
  var defaults = {width: '100%', scrolling: 'auto'};
  var options = $.extend({}, defaults, options);

  return $('<iframe class="media-modal-frame" tabindex="0"/>')
  .attr('src', src)
  .attr('width', options.width)
  .attr('id', id)
  .attr('scrolling', options.scrolling);
};

Drupal.media.popups.overlayDisplace = function (dialog) {
  if (parent.window.Drupal.overlay && jQuery.isFunction(parent.window.Drupal.overlay.getDisplacement)) {
    var overlayDisplace = parent.window.Drupal.overlay.getDisplacement('top');

    if (dialog.offset().top < overlayDisplace) {
      dialog.css('top', overlayDisplace);
    }
  }
}

/**
 * Size the dialog when it is first loaded and keep it centered when scrolling.
 *
 * @param jQuery dialogElement
 *  The element which has .dialog() attached to it.
 */
Drupal.media.popups.sizeDialog = function (dialogElement) {
  if (!dialogElement.is(':visible')) {
    return;
  }

  var windowWidth = $(window).width();
  var dialogWidth = windowWidth * 0.8;
  var windowHeight = $(window).height();
  var dialogHeight = windowHeight * 0.8;

  dialogElement.dialog("option", "width", dialogWidth);
  dialogElement.dialog("option", "height", dialogHeight);
  dialogElement.dialog("option", "position", 'center');

  $('.media-modal-frame').width('100%');
}

/**
 * Resize the dialog when the window changes.
 *
 * @param jQuery dialogElement
 *  The element which has .dialog() attached to it.
 */
Drupal.media.popups.resizeDialog = function (dialogElement) {
  $(window).resize(function() {
    Drupal.media.popups.sizeDialog(dialogElement);
  });
}

/**
 * Keeps the dialog centered when the window is scrolled.
 *
 * @param jQuery dialogElement
 *  The element which has .dialog() attached to it.
 */
Drupal.media.popups.scrollDialog = function (dialogElement) {
  // Keep the dialog window centered when scrolling.
  $(window).scroll(function() {
    if (!dialogElement.is(':visible')) {
      return;
    }

    dialogElement.dialog("option", "position", 'center');
  });
}

})(jQuery);
;
(function ($) {

/**
 * A progressbar object. Initialized with the given id. Must be inserted into
 * the DOM afterwards through progressBar.element.
 *
 * method is the function which will perform the HTTP request to get the
 * progress bar state. Either "GET" or "POST".
 *
 * e.g. pb = new progressBar('myProgressBar');
 *      some_element.appendChild(pb.element);
 */
Drupal.progressBar = function (id, updateCallback, method, errorCallback) {
  var pb = this;
  this.id = id;
  this.method = method || 'GET';
  this.updateCallback = updateCallback;
  this.errorCallback = errorCallback;

  // The WAI-ARIA setting aria-live="polite" will announce changes after users
  // have completed their current activity and not interrupt the screen reader.
  this.element = $('<div class="progress" aria-live="polite"></div>').attr('id', id);
  this.element.html('<div class="bar"><div class="filled"></div></div>' +
                    '<div class="percentage"></div>' +
                    '<div class="message">&nbsp;</div>');
};

/**
 * Set the percentage and status message for the progressbar.
 */
Drupal.progressBar.prototype.setProgress = function (percentage, message) {
  if (percentage >= 0 && percentage <= 100) {
    $('div.filled', this.element).css('width', percentage + '%');
    $('div.percentage', this.element).html(percentage + '%');
  }
  $('div.message', this.element).html(message);
  if (this.updateCallback) {
    this.updateCallback(percentage, message, this);
  }
};

/**
 * Start monitoring progress via Ajax.
 */
Drupal.progressBar.prototype.startMonitoring = function (uri, delay) {
  this.delay = delay;
  this.uri = uri;
  this.sendPing();
};

/**
 * Stop monitoring progress via Ajax.
 */
Drupal.progressBar.prototype.stopMonitoring = function () {
  clearTimeout(this.timer);
  // This allows monitoring to be stopped from within the callback.
  this.uri = null;
};

/**
 * Request progress data from server.
 */
Drupal.progressBar.prototype.sendPing = function () {
  if (this.timer) {
    clearTimeout(this.timer);
  }
  if (this.uri) {
    var pb = this;
    // When doing a post request, you need non-null data. Otherwise a
    // HTTP 411 or HTTP 406 (with Apache mod_security) error may result.
    $.ajax({
      type: this.method,
      url: this.uri,
      data: '',
      dataType: 'json',
      success: function (progress) {
        // Display errors.
        if (progress.status == 0) {
          pb.displayError(progress.data);
          return;
        }
        // Update display.
        pb.setProgress(progress.percentage, progress.message);
        // Schedule next timer.
        pb.timer = setTimeout(function () { pb.sendPing(); }, pb.delay);
      },
      error: function (xmlhttp) {
        pb.displayError(Drupal.ajaxError(xmlhttp, pb.uri));
      }
    });
  }
};

/**
 * Display errors on the page.
 */
Drupal.progressBar.prototype.displayError = function (string) {
  var error = $('<div class="messages error"></div>').html(string);
  $(this.element).before(error).hide();

  if (this.errorCallback) {
    this.errorCallback(this);
  }
};

})(jQuery);
;
/**
 * @file
 * Opens the media browser then edit field
 */

(function ($) {

/**
 * Attach behaviors to media element browse fields.
 */
Drupal.behaviors.oaFilesUpload = {
  attach: function (context, settings) {
    $('a:not(.oa-files-processed)[href*="oa-files/upload"]', context).addClass('oa-files-processed').each(function() {
      var $link = $(this);
      $(this).click(function() {
        Drupal.media.popups.mediaBrowser(function(selected) {
          var browserSrc = settings.oa_files_upload_url + '/';
          for (key in selected) {
            browserSrc += selected[key].fid + '+';
          }
          browserSrc += '/js-return?render=oa-files-popup';
          if ($link[0].search) {
            browserSrc += '&' + $link[0].search.substr(1);
          }
          var mediaIframe = Drupal.media.popups.getPopupIframe(browserSrc, 'oaFilesUpload');
          mediaIframe.bind('load', {}, function (e) {
            // Return can be json or a page, want to act on the json.
            var parsed_json;
            var frame_html = $('#json-encode', this.contentWindow.document).html();
            if (!frame_html) {
              return;
            }
            try {
              parsed_json = JSON.parse(frame_html)
            }
            catch(err) {
              return;
            }
            if (parsed_json) {
              for (var i in parsed_json) {
                if (parsed_json.hasOwnProperty(i) && parsed_json[i]['command'] && Drupal.ajax.prototype.commands[parsed_json[i]['command']]) {
                  Drupal.ajax.prototype.commands[parsed_json[i]['command']](Drupal.ajax.prototype, parsed_json[i], 'success');
                }
              }
              mediaIframe.dialog("close");
            }
          });
          var dialogOptions = Drupal.media.popups.getDialogOptions();
          var dialog = mediaIframe.dialog(dialogOptions);
          Drupal.media.popups.sizeDialog(dialog);
          Drupal.media.popups.resizeDialog(dialog);
          Drupal.media.popups.scrollDialog(dialog);

        }, settings.oa_files_media_options.global, {}, settings.oa_files_media_options.widget);
        return false;
      })
    });
  },
};

})(jQuery);

;
/**
 * @file
 * Integrates d3 library and functionality with D7 core javascript
 */

// polyfill for Array.includes
Array.prototype.includes || Object.defineProperty(Array.prototype, "includes", {
  value: function(r, e) {
    if (null == this) throw new TypeError('"this" is null or not defined');
    var t = Object(this),
      n = t.length >>> 0;
    if (0 === n) return !1;
    var i, o, a = 0 | e,
      u = Math.max(a >= 0 ? a : n - Math.abs(a), 0);
    for (; u < n;) {
      if ((i = t[u]) === (o = r) || "number" == typeof i && "number" == typeof o && isNaN(i) && isNaN(o)) return !0;
      u++
    }
    return !1
  }
});

(function($, Drupal) {
  Drupal.behaviors.d3_config_form = {
    attach: function(context, settings) {

      var source_select = $('.form-item-d3-library-source select');

      //this is for setting up options on page load
      test();

      source_select.change(test);

      function test() {
        var selected = source_select.val();
        var ok_versions = d3_library_versions[selected];
        $('.form-item-d3-library-version option').each(function() {
          $(this).attr('disabled',!ok_versions.includes($(this).val()));
        });
      }
    }
  };
})(jQuery, Drupal);
;
