/**
 * @file
 * JS from Radix.
 *
 * To enable mouseover for menus, see code in oa_toolbar/js/oa_toolbar.js
 */
(function ($, Drupal, window, document, undefined) {
  // Allow dropdown links to be clickable by showing dropdowns on hover/focus.
  Drupal.behaviors.radix_dropdown = {
    attach: function(context, setting) {
      $('.dropdown').once('radix-dropdown', function(){
        var dropdown = this;

        // Helper function to show the dropdown.
        function show() {
          if (!$(dropdown).hasClass('open')) {
            $('>[data-toggle="dropdown"]', dropdown).trigger('click.bs.dropdown');
          }
        }

        // Helper function to hide the dropdown.
        function hide() {
          if ($(dropdown).hasClass('open')) {
            $('>[data-toggle="dropdown"]', dropdown).trigger('click.bs.dropdown');
          }
        }

        // Show dropdown on hover and focus.
        $(this).on('mouseenter.radix.dropdown', function(e) {
          show();
        });
        $(this).on('mouseleave.radix.dropdown', function(e) {
          hide();
        });
        $(this).on('focusin.radix.dropdown', function(e) {
          if (typeof e.isSimulated == 'undefined') {
            // don't trigger on simulated event, like when window gets focused
            show();
          }
        });
        $('body').once('radix-dropdown').on('focusout.radix.dropdown', function(e) {
          var parent = $(e.target).closest('li.radix-dropdown-processed.open').get(0);
          if (parent) {
            // Defer to after all handlers so we can see where focus landed.
            setTimeout(function () {
              // Don't do anything if no element is focused - that can only
              // happen with the mouse and this is meant to close the menu
              // when the keyboard is used to change focus.
              if (!document.activeElement || document.activeElement === document.body) {
                return;
              }
              // Hide the parent if it doesn't contain the now focused element
              // and is still open.
              if (!parent.contains(document.activeElement) && $(parent).hasClass('open')) {
                $(parent).trigger('click.bs.dropdown');
              }
            }, 0);
          }
        });

        $(this).on('keydown.radix.dropdown', function(e) {
          // Prevent up/down arrow from doing anything -- they conflict with
          // using focus to show the dropdown, and the default Bootstrap keydown
          // handler will trigger our click handler to visit the link.
          if (e.keyCode == 38 || e.keyCode == 40) {
            return false;
          }
          // Show/hide dropdown with spacebar.
          if (e.keyCode == 32) {
            $('>[data-toggle="dropdown"]', dropdown).trigger('click.bs.dropdown');
            return false;
          }
          // Hide the dropdown with the escape hey.
          if (e.keyCode == 27) {
            // Leave focus on the parent after it's hidden.
            $('>[data-toggle="dropdown"]', dropdown).focus();
            hide();
            return false;
          }
        });

        // Allow a.dropdown-toggle to be clickable.
        if ($(this).has('> a.dropdown-toggle')) {
          $(this).on('click.radix.dropdown', function(e) {
            var $target = $(e.target);
            if ($target.parent().get(0) == dropdown && $target.is('a.dropdown-toggle') && $target.attr('href')) {
              e.preventDefault();
              window.location.href = $target.attr('href');
            }
          });
        }
      });
    }
  }

  // Bootstrap tooltip.
  Drupal.behaviors.radix_tooltip = {
    attach: function(context, setting) {
      if ($.fn.tooltip) {
        $("[data-toggle='tooltip']").tooltip();
      }
    }
  }

  // Bootstrap popover.
  Drupal.behaviors.radix_popover = {
    attach: function(context, setting) {
      if ($.fn.popover) {
        $("[data-toggle='popover']").popover();
      }
    }
  }

  $(document).ready(function() {
    // Show first tab by default.
    // Ignore the "primary" tabs on the node edit page.
    if ($.fn.tab) {
      var tabs = $('.nav-tabs').not('.primary');
      tabs.children('li').first().find('a').tab('show');

      if (hash = window.location.hash) {
        $('.nav-tabs > li > a[href$="' + hash + '"]').tab('show');
      }
    }
  });
})(jQuery, Drupal, this, this.document);
;
'use strict';

(function ($) {
  $(document).ready(function () {
    // Handle toolbar collapse.
    $('.oa-navigation .btn-navbar-menu').click(function (e) {
      e.preventDefault();
      var navMenuCollapse = $('.oa-navigation .nav-menu-collapse');
      var height = navMenuCollapse.height() == 0 ? 'auto' : 0;
      navMenuCollapse.height(height);
    });

    // adjust the position of the IPE buttons
    var $ipe = $('#panels-ipe-control-container');
    if ($ipe.length) {
      var $main = $('#main');
      var $element = $ipe.detach();
      $main.prepend($element);
    }

    var toggleLeft = $('.oa-responsive-regions-toggle-left:visible');
    if (toggleLeft.length > 0) {
      $('body').addClass('oa-responsive-left');
    }

    $(window).resize(function () {
      // Fix for positioning of save button on modules page.
      if ($('#module-filter-submit.fixed-bottom') && $('.oa-layout-footer')) {
        $('html.js #module-filter-submit.fixed-bottom').css('bottom', $('.oa-layout-footer').outerHeight());
      }
    }).resize();
  });

  Drupal.behaviors.oa_wysiwyg = {
    attach: function attach(context, settings) {
      // Tweak the WYSIWYG selector on text fields
      $('form .format-toggle', context).once("description-processed", function () {
        var parent = $(this).parents('.text-format-wrapper');
        var hasLabel = parent.find('.form-type-textarea:visible label');
        var visible = hasLabel.is(':visible') && !hasLabel.hasClass('element-invisible');
        var hasDescription = parent.find('.description');
        if (hasDescription.length > 0) {
          hasDescription.insertAfter(hasLabel);
        }
        if (visible) {
          if (hasDescription.length > 0) {
            $(this).insertAfter(hasDescription);
            $(this).addClass('has-description');
            hasDescription.addClass('has-wysiwyg');
            $(this).css('top', hasDescription.height() - $(this).height() + 20 + 'px');
          }
        }
      });
    }
  };

  Drupal.behaviors.fieldset_collapse = {
    attach: function attach(context, settings) {
      // allow chosen dropdowns within fieldsets to be visible
      if ('chosen' in settings) {
        var selector = settings.chosen.selector;
        $(selector, context).not('#field-ui-field-overview-form select, #field-ui-display-overview-form select, .wysiwyg, .draggable select[name$="[weight]"], .draggable select[name$="[position]"]') //disable chosen on field ui
        .each(function () {
          $(this).parents('.panel-body.fieldset-wrapper, .form-item.form-type-select').first().addClass('chosen-fieldset-wrapper');
        });
      }
    }
  };

  if (Drupal.CTools && typeof Drupal.CTools.CollapsibleCallbacksAfterToggle != 'undefined') {
    Drupal.CTools.CollapsibleCallbacksAfterToggle[Drupal.CTools.CollapsibleCallbacksAfterToggle.length] = function ($container, handle, content, toggle) {
      // Older versions of jquery leave behind a overflow:hidden;
      // @see https://www.drupal.org/node/2408807
      if (content.css("overflow") == "hidden") {
        content.css("overflow", "");
      }
    };
  }

  Drupal.behaviors.fixModulesButton = {
    attach: function attach(context) {
      $(window).resize(function () {
        // Fix for positioning of save button on modules page.
        if ($('#module-filter-submit.fixed-bottom') && $('.oa-layout-footer')) {
          $('html.js #module-filter-submit.fixed-bottom').css('bottom', $('.oa-layout-footer').outerHeight());
        }
      });
    }
  };

  Drupal.behaviors.scrollingMenus = {
    attach: function attach(context, settings) {
      $('.oa_toolbar .dropdown-menu', context).not('oa-no-scroll').once('oa-scroll', function () {
        // Compute max height for menus to scroll
        var viewport = $(window).height();
        // Cannot compute top of hidden objects, so briefly show the menu
        // This shouldn't cause flicker in most browsers these days.
        // Also need to show any parent menus
        if ($(this).parent().hasClass('dropdown-submenu')) {
          $(this).parents('.dropdown-menu').css('display', 'block');
        }
        $(this).css('display', 'block');
        var max_height = viewport - $(this).offset().top - 20;
        $(this).css('display', '');
        if ($(this).parent().hasClass('dropdown-submenu')) {
          $(this).parents('.dropdown-menu').css('display', '');
        }
        $(this).css('max-height', max_height + 'px');
      });
    }
  };
})(jQuery);
;
/**
 * @file
 * Custom scripts for theme.
 */
(function ($) {
  Drupal.behaviors.hideEmptyPanes = {
    attach: function (context, settings) {
      $('#main-wrapper .panel-pane, .pane-pane-oa-form-actions', context).each(function () {
        // Look for empty panels that also don't contain input fields
        // (input fields don't generate text()
        if ($(this).find('input,img,.geofieldMap').length == 0 && $(this).text().trim().length == 0) {
          $(this).css('display', 'none');
        }
      });
      // Check the edit panel at bottom AFTER we have done the above hiding
      $('.pane-oa-edit-minipanel .radix-layouts-content', context).each(function () {
        var text = $(this).find('.panel-pane:visible').text();
        if (text.trim().length == 0) {
          $(this).css('display', 'none');
        }
      });
      $('.oa-responsive-regions-toggle-left', context).each(function () {
        $(this).bind('click', function() {
          $('.navbar-tray').removeClass('active');
        });
      });
    }
  };
})(jQuery);
;
